@@ -8,8 +8,7 @@ Date: 2020-06-29 11:12
 Desc:
 '''
 
-# from ._waterfall import waterfall
-from ._waterfall import waterfall_legacy as waterfall
+from ._waterfall import waterfall
 from ._force import force
 # from ._beeswarm import beeswarm
 from ._beeswarm import summary_legacy as summary_plot
